@@ -12,7 +12,7 @@ from fl4health.client_managers.base_sampling_manager import BaseSamplingManager
 class FixedSamplingWithoutReplacementClientManager(BaseSamplingManager):
     """Overrides the Simple Client Manager to Provide Fixed Sampling without replacement for Clients"""
 
-    def sample(
+    def sample_fraction(
         self,
         sample_fraction: float,
         # minimum number of clients required to be available
@@ -20,16 +20,8 @@ class FixedSamplingWithoutReplacementClientManager(BaseSamplingManager):
         criterion: Optional[Criterion] = None,
     ) -> List[ClientProxy]:
         """Sample a number of Flower ClientProxy instances."""
-        if min_num_clients is not None:
-            self.wait_for(min_num_clients)
-        else:
-            # Wait for at least one client to be available
-            self.wait_for(1)
-        # Sample clients which meet the criterion
-        available_cids = list(self.clients)
-        if criterion is not None:
-            available_cids = [cid for cid in available_cids if criterion.select(self.clients[cid])]
 
+        available_cids = self.wait_and_filter(min_num_clients, criterion)
         n_available_cids = len(available_cids)
         num_to_sample = int(sample_fraction * n_available_cids)
         if num_to_sample < 1:
